@@ -1,6 +1,7 @@
 varImp.lm <- function(object, ...) 
 {
-   varImps <-  abs(summary(object)$coef[-1, "t value"])
+  values <- summary(object)$coef
+   varImps <-  abs(values[-1, grep("value$", colnames(values))])
    out <- data.frame(varImps)
    colnames(out) <- "Overall"
    if(!is.null(names(varImps))) rownames(out) <- names(varImps)
